package com.cweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.DateUtil;
import com.hai.common.utils.IDGenerator;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighOrder;
import com.hai.entity.OutRechargeOrder;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.service.OutRechargeOrderService;
import com.hai.service.TelApiService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value = "/outRechargeOrder")
@Api(value = "充值订单接口")
public class OutRechargeOrderController {
    private static Logger log = LoggerFactory.getLogger(HighMerchantStoreController.class);

    @Autowired
    private UserCenter userCenter;

    @Resource
    private OutRechargeOrderService outRechargeOrderService;

    @Resource
    private TelApiService telApiService;

    @RequestMapping(value="/addOrder",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "增加订单")
    public ResponseData addOrder(@RequestBody OutRechargeOrder outRechargeOrder, HttpServletRequest request) {
        try {

            // 用户
//            SessionObject sessionObject = userCenter.getSessionObject(request);
//            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();
//            if(sessionObject == null){
//                log.error("SecOrganizationController --> addOrganization() error!", "");
//                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
//            }
            if (StringUtils.isBlank(outRechargeOrder.getRechargeContent()) ||
                    outRechargeOrder.getPayPrice() == null ||
                    outRechargeOrder.getOrderPrice() == null
            ) {
                log.error("orderToPay error!");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            String remarks = "";
            // 支付类型 1.微信支付
            outRechargeOrder.setPayType(1);
            // 判断充值模式：1 话费充值 2. 中石化 3. 中石油
            if (outRechargeOrder.getRechargeModel() == 1) {
                JSONObject telObject = telApiService.outApiTel(outRechargeOrder.getRechargeContent());
                if (telObject.get("status").equals(0)) {
                    JSONObject o = telObject.getObject("result",JSONObject.class);
                    // 拼接内容
                    remarks = o.get("province").toString() +  o.get("company").toString() + "充值" + outRechargeOrder.getOrderPrice() + "元";
                } else {
                    log.error("orderToPay error!");
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.PHONE_NUM_IS_ERROR);
                }
            } else if (outRechargeOrder.getRechargeModel() == 2) {
                remarks = "中石化充值" + outRechargeOrder.getOrderPrice() + "元";
            } else if (outRechargeOrder.getRechargeModel() == 3 ) {
                // 中石油需要姓名和身份证号
                if (StringUtils.isBlank(outRechargeOrder.getRechargeName()) ||
                        StringUtils.isBlank(outRechargeOrder.getIdCard())
                ) {
                    log.error("orderToPay error!");
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
                remarks = "中石油充值" + outRechargeOrder.getOrderPrice() + "元";
            } else {
                log.error("orderToPay error!");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            outRechargeOrder.setRemarks(remarks);
            outRechargeOrder.setOrderNo("CZ" + DateUtil.date2String(new Date(),"yyyyMMddHHmmss") + IDGenerator.nextId(5));
//            outRechargeOrder.setUserId(userInfoModel.getHighUser().getId());
//            outRechargeOrder.setUserName(userInfoModel.getHighUser().getName());
//            outRechargeOrder.setUserPhone(userInfoModel.getHighUser().getPhone());
            outRechargeOrder.setUserId(2L);
            outRechargeOrder.setUserName("袁野");
            outRechargeOrder.setUserPhone("18090580471");
            outRechargeOrder.setCreateTimed(new Date());
            outRechargeOrder.setStatus(1);
            outRechargeOrderService.insertOrder(outRechargeOrder);
            return ResponseMsgUtil.success(outRechargeOrder);

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/getOrderById", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据id查询订单详情")
    public ResponseData getOrderById(@RequestParam(name = "orderId", required = true) Long orderId) {
        try {

            return ResponseMsgUtil.success(outRechargeOrderService.findByOrderId(orderId));

        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/cancelOrder", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "取消订单")
    public ResponseData cancelOrder(@RequestParam(name = "orderId", required = true) Long orderId) {
        try {

            OutRechargeOrder outRechargeOrder  = outRechargeOrderService.findByOrderId(orderId);

            if (outRechargeOrder.getStatus() == 1) {
                outRechargeOrderService.cancelOrder(orderId);
            } else {
                log.error("orderToPay error!");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.STATUS_ERROR, "");
            }

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighOrderController --> cancelOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getUserOrderList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取用户订单")
    public ResponseData getUserOrderList(
            @RequestParam(name = "status", required = false) Integer status,
            @RequestParam(name = "orderNo", required = false) String orderNo,
            @RequestParam(name = "rechargeModel", required = false) String rechargeModel,
            @RequestParam(name = "pageNum", required = true) Integer pageNum,
            @RequestParam(name = "pageSize", required = true) Integer pageSize,
            HttpServletRequest request) {
        try {

            // 用户
//            SessionObject sessionObject = userCenter.getSessionObject(request);
//            HighUserModel userInfoModel = (HighUserModel) sessionObject.getObject();

            Map<String,String> map = new HashMap<>();
//            map.put("userId", userInfoModel.getHighUser().getId().toString());
            map.put("userId", "2");
            if (status != null) {
                map.put("status", status.toString());
            }
            if (StringUtils.isNotBlank(orderNo)) {
                map.put("orderNo", orderNo);
            }
            if (StringUtils.isNotBlank(rechargeModel)) {
                map.put("rechargeModel", rechargeModel);
            }

            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(outRechargeOrderService.getListRechargeOrder(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getUserOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
